﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Windows;
using Microsoft.Win32;
using Telerik.Windows.Controls;
using Telerik.Windows.Documents;
using Telerik.Windows.Documents.FormatProviders;
using Telerik.Windows.Documents.Model;

namespace RadBook
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private const string SampleDocumentPath = "SampleData/RichTextBoxSample.xaml";

        private RadDocumentBindingSource bindingSource = new RadDocumentBindingSource();
        private DocumentViewManager viewManager;

        public MainWindow()
        {
            InitializeComponent();

            this.viewManager = (DocumentViewManager)this.Resources["viewManager"];
            this.Loaded += UserControl_Loaded;
        }

        private void LoadDocument(Stream stream, string extension)
        {
            RadDocument doc;

            IDocumentFormatProvider provider = DocumentFormatProvidersManager.GetProviderByExtension(extension);
            if (provider != null)
            {
                doc = provider.Import(stream);
            }
            else
            {
                MessageBox.Show("Unknown format.");
                return;
            }

            doc.LayoutMode = DocumentLayoutMode.Paged;

            doc.Measure(RadDocument.MAX_DOCUMENT_SIZE);
            doc.Arrange(new RectangleF(PointF.Empty, doc.DesiredSize));
            
            this.book.RightPageIndex = 0;

            this.viewManager.Document = doc;
            bindingSource.Document = doc;
        }

        private Uri GetResourceUri(string resource)
        {
            AssemblyName assemblyName = new AssemblyName(this.GetType().Assembly.FullName);
            string resourcePath = "/" + assemblyName.Name + ";component/" + resource;
            Uri resourceUri = new Uri(resourcePath, UriKind.Relative);

            return resourceUri;
        }

        private void UserControl_Loaded(object sender, RoutedEventArgs e)
        {
            using (Stream stream = Application.GetResourceStream(this.GetResourceUri(SampleDocumentPath)).Stream)
            {
                this.LoadDocument(stream, ".xaml");
            }
            this.book.ItemsSource = bindingSource;
        }

        private void buttonOpen_Click(object sender, RoutedEventArgs e)
        {
            OpenFileDialog ofd = new OpenFileDialog();
            ofd.Filter = "Word Documents (*.docx)|*.docx|Web Pages (*.htm,*.html)|*.htm;*.html|Rich Text Format (*.rtf)|*.rtf|Text Files (*.txt)|*.txt|XAML Files (*.xaml)|*.xaml";

            if (ofd.ShowDialog() == true)
            {
                Stream stream;
                stream = ofd.OpenFile();

                using (stream)
                {
                    string extension;
                    extension = Path.GetExtension(ofd.FileName);

                    this.LoadDocument(stream, extension);
                }
            }
        }
    }
}